@@ -1,5 +1,5 @@
 package Dependency::Resolver;
-$Dependency::Resolver::VERSION = '0.06';
+$Dependency::Resolver::VERSION = '0.07';
 use utf8;
 use Moose;
 
@@ -109,10 +109,13 @@ sub get_modules{
     my $ver  = shift || 0;
     $op = '==' if $op eq '=';
 
+
+    die "Operator '$op' is unknown"
+        if (! grep { $op eq $_ } qw(== != < > >= <= ));
+
     my $modules = [];
     foreach my $m (@{$self->modules->{$mod}}){
         my $mver = $m->{version};
-
         if ( eval "$mver $op $ver"  ){
             push(@$modules, $m);
         }
@@ -127,39 +130,41 @@ Dependency::Resolver - Simple Dependency resolving algorithm
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 based on http://www.electricmonk.nl/log/2008/08/07/dependency-resolving-algorithm/
 
 =head1 SYNOPSIS
 
-  my $a  = { name => 'A' , version => 1, deps => [ 'B == 1', 'D']};
-  my $a2 = { name => 'A' , version => 2, deps => [ 'B => 2, B < 3', 'D']};
-  my $b1 = { name => 'B' , version => 1, deps => [ 'C == 1',  'E'] };
-  my $b2 = { name => 'B' , version => 2, deps => [ 'C == 2',  'E'] };
-  my $b3 = { name => 'B' , version => 3, deps => [ 'C == 3',  'E'] };
-  my $c1 = { name => 'C' , version => 1, deps => [ 'D', 'E'] };
-  my $c2 = { name => 'C' , version => 2, deps => [ 'D', 'E'] };
-  my $c3 = { name => 'C' , version => 3, deps => [ 'D', 'E'] };
-  my $d  = { name => 'D' , version => 1};
-  my $e  = { name => 'E' , version => 1};
+build dependencies tree
 
-  my $resolver = Dependency::Resolver->new;
+    my $a  = { name => 'A' , version => 1, deps => [ 'B == 1', 'D']};
+    my $a2 = { name => 'A' , version => 2, deps => [ 'B => 2, B < 3', 'D']};
+    my $b1 = { name => 'B' , version => 1, deps => [ 'C == 1',  'E'] };
+    my $b2 = { name => 'B' , version => 2, deps => [ 'C == 2',  'E'] };
+    my $b3 = { name => 'B' , version => 3, deps => [ 'C == 3',  'E'] };
+    my $c1 = { name => 'C' , version => 1, deps => [ 'D', 'E'] };
+    my $c2 = { name => 'C' , version => 2, deps => [ 'D', 'E'] };
+    my $c3 = { name => 'C' , version => 3, deps => [ 'D', 'E'] };
+    my $d  = { name => 'D' , version => 1};
+    my $e  = { name => 'E' , version => 1};
 
-  my $resolved = $resolver->dep_resolv($a);
-  #  return [ $d, $e, $c1, $b1, $a ]
+    my $resolver = Dependency::Resolver->new;
 
-  $resolved = $resolver->dep_resolv($a2);
-  # return [ $d, $e, $c2, $b2, $a2 ]
+    my $resolved = $resolver->dep_resolv($a);
+    #  return [ $d, $e, $c1, $b1, $a ]
 
-  # method used by dep_resolv (get_module, search_best_dep)
-  $resolver->get_modules('B', '==', 1); # return  [$b1]
-  $resolver->get_modules('B', '<=', 2); # return  [$b1, $b2]
-  $resolver->get_modules('B', '>=', 1); # return  [$b1, $b2, $b3]
+    $resolved = $resolver->dep_resolv($a2);
+    # return [ $d, $e, $c2, $b2, $a2 ]
 
-  $resolver->search_best_dep('B >= 1');       # return $b3 (highest version)
-  $resolver->search_best_dep('B >= 1, B!=3');       # return $b2
-  $resolver->search_best_dep('B >= 1, B<=3, B!=3'); # return $b2
+    # method used by dep_resolv (get_module, search_best_dep)
+    $resolver->get_modules('B', '==', 1); # return  [$b1]
+    $resolver->get_modules('B', '<=', 2); # return  [$b1, $b2]
+    $resolver->get_modules('B', '>=', 1); # return  [$b1, $b2, $b3]
+
+    $resolver->search_best_dep('B >= 1');       # return $b3 (highest version)
+    $resolver->search_best_dep('B >= 1, B!=3');       # return $b2
+    $resolver->search_best_dep('B >= 1, B<=3, B!=3'); # return $b2
 
 
 =head1 SUBROUTINES/METHODS
